# python_CINI_selector

This repository that build and is the standard CINI selector for differrent use.

The oficial description of the requisites of the CINI code are writed on: https://www.boe.es/diario_boe/txt.php?id=BOE-A-2019-6181

## Installation

Once activate your python environment. use as standard pip installation: 

````
pip install CINI-selector
````
